==> haskell-http-client-tls-0.3.6.4-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-J66XMKhNiAS32Xk62TKvnN
key:                  http-client-tls-0.3.6.4-J66XMKhNiAS32Xk62TKvnN
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  d446b19efae2b62954c2f6c9c2db7090
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-J66XMKhNiAS32Xk62TKvnN
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-AMgBCf5fDYf4pbGdLaLtss containers-0.6.7
    crypton-1.0.4-6r7difyxiE08uhXDhecjzk
    crypton-connection-0.4.5-EJG9Su3gRZG9luCx49hjkn
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd exceptions-0.10.5
    http-client-0.7.19-4UbGlDhlNmJ9JhWVX5eNPs
    http-types-0.12.4-8EgajALSM5xB8GFkN9ClFd
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-Ez30o8Wyt6m7hXZSCgqaWo
    network-uri-2.6.4.2-Db65q7JXyy8EWWIZuTCsbL text-2.0.2
    tls-2.0.6-ECImkZrQc0LGRli4SMucco transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.4-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-26jJPqfpxqfJih66sxENJC
key:                  http-client-tls-0.3.6.4-26jJPqfpxqfJih66sxENJC
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  ca7f3dcc2226e52310a5bcbe8aeb5d19
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-26jJPqfpxqfJih66sxENJC
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-rTys5srD4l50KQCiQKWYt containers-0.6.7
    crypton-1.0.4-3YH9347FRArGwqZdh3IBCs
    crypton-connection-0.4.5-A2ovQOewUTk2uElvkVK9wg
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd exceptions-0.10.5
    http-client-0.7.19-1818a0SJLwXE4QrSYiVT7V
    http-types-0.12.4-8KsSLLTB3zVcsjL7f3kez
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-5tdSDQBC1SF9do6vOgsoy3
    network-uri-2.6.4.2-60V3uLcyBv8HHhnYdb8knn text-2.0.2
    tls-2.0.6-F4zPn0fr5WK8gHgPjNtUZF transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
